AuthKey class

Holds the authorization key data and computes the auxiliary hash and key ID from the SHA-1 digest of the key.

Constructors

AuthKey(Uint8List? data)
Creates an AuthKey from the given data bytes.

Properties

auxHash int?
The auxiliary hash derived from the first 8 bytes of SHA-1(key).
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
isValid bool
Whether this key contains valid data.
no setter
key Uint8List?
Returns the raw key bytes.
getter/setter pair
keyId int?
The key ID derived from bytes 12..20 of SHA-1(key).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

calcNewNonceHash(BigInt newNonce, int number) BigInt
Calculates the new nonce hash based on the current key attributes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override