RSA class

Provides RSA encryption using Telegram's server public keys.

Server keys are stored by fingerprint. The fingerprint is computed as the last 8 bytes of SHA-1(serialize_bytes(n) + serialize_bytes(e)), interpreted as a little-endian signed 64-bit integer.

Constructors

RSA()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fingerprints List<int>
Returns a list of all known fingerprints.
no setter

Static Methods

encrypt(int fingerprint, Uint8List data, {bool useOld = false}) Uint8List?
Encrypts data with the server key matching fingerprint.