Authenticator class
Performs the MTProto authentication key exchange.
This is a multi-step protocol that negotiates an auth key between the client and a Telegram DC using Diffie-Hellman over a plain (unencrypted) MTProto connection.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
doAuthentication(
MTProtoPlainSender sender) → Future< (AuthKey, int)> - Performs the full authentication handshake and returns a tuple of (auth_key, time_offset).
-
generateTempAesKeyIv(
BigInt serverNonce, BigInt newNonce) → (Uint8List, Uint8List) - Generates temporary AES key and IV from nonce values for DH parameter decryption during the key exchange.