InvalidChecksumError class
Thrown when a packet's CRC32 checksum does not match the expected value.
- Inheritance
-
- Object
- TeleFlutterError
- InvalidChecksumError
Constructors
- InvalidChecksumError(int checksum, int validChecksum)
Properties
- checksum → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validChecksum → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited